# coding: utf-8

# flake8: noqa

"""
    OurSky SDA

    The basic flow for a new organization is as follows: 1. View the available satellite targets with the [satellite targets](#operation/v1GetSatelliteTargets) endpoint. Copy the id of the target you want to observe. 2. Create an organization target with the [organization target](#operation/v1CreateOrganizationTarget) endpoint. Use the id copied from above. 3. Create a webhook with the [webhook](#operation/v1CreateWebhookConfiguration) endpoint to receive TDMs automatically (preferred) or use the [tdms](#operation/v1GetTdms) endpoint to poll for TDMs.

    The version of the OpenAPI document: 1.3.1905
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


__version__ = "1.3.1905"

# import apis into sdk package
from ourskyai_sda_api.api.default_api import DefaultApi

# import ApiClient
from ourskyai_sda_api.api_response import ApiResponse
from ourskyai_sda_api.api_client import ApiClient
from ourskyai_sda_api.configuration import Configuration
from ourskyai_sda_api.exceptions import OpenApiException
from ourskyai_sda_api.exceptions import ApiTypeError
from ourskyai_sda_api.exceptions import ApiValueError
from ourskyai_sda_api.exceptions import ApiKeyError
from ourskyai_sda_api.exceptions import ApiAttributeError
from ourskyai_sda_api.exceptions import ApiException

# import models into sdk package
from ourskyai_sda_api.models.astrometric_offsets import AstrometricOffsets
from ourskyai_sda_api.models.empty_success import EmptySuccess
from ourskyai_sda_api.models.filter_type import FilterType
from ourskyai_sda_api.models.observation_result import ObservationResult
from ourskyai_sda_api.models.orbit_type import OrbitType
from ourskyai_sda_api.models.successful_create import SuccessfulCreate
from ourskyai_sda_api.models.tracking_type import TrackingType
from ourskyai_sda_api.models.v1_create_image_set_image_request import V1CreateImageSetImageRequest
from ourskyai_sda_api.models.v1_create_image_set_image_response import V1CreateImageSetImageResponse
from ourskyai_sda_api.models.v1_create_image_set_request import V1CreateImageSetRequest
from ourskyai_sda_api.models.v1_create_organization_target_request import V1CreateOrganizationTargetRequest
from ourskyai_sda_api.models.v1_get_satellite_targets_response import V1GetSatelliteTargetsResponse
from ourskyai_sda_api.models.v1_image_set import V1ImageSet
from ourskyai_sda_api.models.v1_image_set_image import V1ImageSetImage
from ourskyai_sda_api.models.v1_observation_sequence_result import V1ObservationSequenceResult
from ourskyai_sda_api.models.v1_observation_sequence_result_image_sets_inner import V1ObservationSequenceResultImageSetsInner
from ourskyai_sda_api.models.v1_organization_target import V1OrganizationTarget
from ourskyai_sda_api.models.v1_satellite_potential import V1SatellitePotential
from ourskyai_sda_api.models.v1_satellite_target import V1SatelliteTarget
from ourskyai_sda_api.models.v1_tdm import V1Tdm
from ourskyai_sda_api.models.v1_update_email_configuration_request import V1UpdateEmailConfigurationRequest
from ourskyai_sda_api.models.v1_update_webhook_configuration_request import V1UpdateWebhookConfigurationRequest
from ourskyai_sda_api.models.v1_webhook_configuration import V1WebhookConfiguration
from ourskyai_sda_api.models.webhook_event import WebhookEvent



# coding: utf-8

"""
    OurSky SDA

    The basic flow for a new organization is as follows: 1. View the available satellite targets with the [satellite targets](#operation/v1GetSatelliteTargets) endpoint. Copy the id of the target you want to observe. 2. Create an organization target with the [organization target](#operation/v1CreateOrganizationTarget) endpoint. Use the id copied from above. 3. Create a webhook with the [webhook](#operation/v1CreateWebhookConfiguration) endpoint to receive TDMs automatically (preferred) or use the [tdms](#operation/v1GetTdms) endpoint to poll for TDMs.

    The version of the OpenAPI document: 1.3.1905
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import json
import pprint
import re  # noqa: F401
from aenum import Enum, no_arg





class FilterType(str, Enum):
    """
    FilterType
    """

    """
    allowed enum values
    """
    NONE = 'NONE'
    RED = 'RED'
    BLUE = 'BLUE'
    GREEN = 'GREEN'
    UV = 'UV'
    IR = 'IR'
    LUMINANCE = 'LUMINANCE'
    ENHANCED_LUMINANCE = 'ENHANCED_LUMINANCE'
    H_ALPHA = 'H_ALPHA'
    H_BETA = 'H_BETA'
    S_II = 'S_II'
    O_III = 'O_III'
    DUAL_BAND = 'DUAL_BAND'
    PHOTO_JOHNSON_U = 'PHOTO_JOHNSON_U'
    PHOTO_JOHNSON_B = 'PHOTO_JOHNSON_B'
    PHOTO_JOHNSON_V = 'PHOTO_JOHNSON_V'
    PHOTO_COUSINS_R = 'PHOTO_COUSINS_R'
    PHOTO_COUSINS_I = 'PHOTO_COUSINS_I'

    @classmethod
    def from_json(cls, json_str: str) -> FilterType:
        """Create an instance of FilterType from a JSON string"""
        return FilterType(json.loads(json_str))





# coding: utf-8

"""
    OurSky SDA

    The basic flow for a new organization is as follows: 1. View the available satellite targets with the [satellite targets](#operation/v1GetSatelliteTargets) endpoint. Copy the id of the target you want to observe. 2. Create an organization target with the [organization target](#operation/v1CreateOrganizationTarget) endpoint. Use the id copied from above. 3. Create a webhook with the [webhook](#operation/v1CreateWebhookConfiguration) endpoint to receive TDMs automatically (preferred) or use the [tdms](#operation/v1GetTdms) endpoint to poll for TDMs.

    The version of the OpenAPI document: 1.3.1905
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json


from typing import Optional
from pydantic import BaseModel, Field, StrictStr
from ourskyai_sda_api.models.filter_type import FilterType
from ourskyai_sda_api.models.tracking_type import TrackingType

class V1CreateImageSetRequest(BaseModel):
    """
    V1CreateImageSetRequest
    """
    target_id: StrictStr = Field(..., alias="targetId")
    node_id: StrictStr = Field(..., alias="nodeId")
    observation_id: Optional[StrictStr] = Field(None, alias="observationId")
    tracking_type: Optional[TrackingType] = Field(None, alias="trackingType")
    filter_type: Optional[FilterType] = Field(None, alias="filterType")
    __properties = ["targetId", "nodeId", "observationId", "trackingType", "filterType"]

    class Config:
        """Pydantic configuration"""
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> V1CreateImageSetRequest:
        """Create an instance of V1CreateImageSetRequest from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> V1CreateImageSetRequest:
        """Create an instance of V1CreateImageSetRequest from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return V1CreateImageSetRequest.parse_obj(obj)

        _obj = V1CreateImageSetRequest.parse_obj({
            "target_id": obj.get("targetId"),
            "node_id": obj.get("nodeId"),
            "observation_id": obj.get("observationId"),
            "tracking_type": obj.get("trackingType"),
            "filter_type": obj.get("filterType")
        })
        return _obj





# coding: utf-8

"""
    OurSky SDA

    The basic flow for a new organization is as follows: 1. View the available satellite targets with the [satellite targets](#operation/v1GetSatelliteTargets) endpoint. Copy the id of the target you want to observe. 2. Create an organization target with the [organization target](#operation/v1CreateOrganizationTarget) endpoint. Use the id copied from above. 3. Create a webhook with the [webhook](#operation/v1CreateWebhookConfiguration) endpoint to receive TDMs automatically (preferred) or use the [tdms](#operation/v1GetTdms) endpoint to poll for TDMs.

    The version of the OpenAPI document: 1.3.1905
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from datetime import datetime
from typing import Optional, Union
from pydantic import BaseModel, Field, StrictFloat, StrictInt, StrictStr
from ourskyai_sda_api.models.astrometric_offsets import AstrometricOffsets

class ObservationResult(BaseModel):
    """
    A single observation result. This is a 1:1 mapping with a single image  # noqa: E501
    """
    image_id: StrictStr = Field(..., alias="imageId")
    astrometric_offsets: AstrometricOffsets = Field(..., alias="astrometricOffsets")
    image_url: Optional[StrictStr] = Field(None, alias="imageUrl")
    ra: Union[StrictFloat, StrictInt] = Field(...)
    dec: Union[StrictFloat, StrictInt] = Field(...)
    timestamp: datetime = Field(...)
    apparent_magnitude: Optional[Union[StrictFloat, StrictInt]] = Field(None, alias="apparentMagnitude", description="BETA: the apparent magnitude of the target at the time of the observation")
    __properties = ["imageId", "astrometricOffsets", "imageUrl", "ra", "dec", "timestamp", "apparentMagnitude"]

    class Config:
        """Pydantic configuration"""
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> ObservationResult:
        """Create an instance of ObservationResult from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        # override the default output from pydantic by calling `to_dict()` of astrometric_offsets
        if self.astrometric_offsets:
            _dict['astrometricOffsets'] = self.astrometric_offsets.to_dict()
        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> ObservationResult:
        """Create an instance of ObservationResult from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return ObservationResult.parse_obj(obj)

        _obj = ObservationResult.parse_obj({
            "image_id": obj.get("imageId"),
            "astrometric_offsets": AstrometricOffsets.from_dict(obj.get("astrometricOffsets")) if obj.get("astrometricOffsets") is not None else None,
            "image_url": obj.get("imageUrl"),
            "ra": obj.get("ra"),
            "dec": obj.get("dec"),
            "timestamp": obj.get("timestamp"),
            "apparent_magnitude": obj.get("apparentMagnitude")
        })
        return _obj


